@@ -43,6 +43,19 @@ class MongoBaseModel(metaclass=ABCMeta):
     def __init__(self, **kwargs):
         pass
 
+    @classmethod
+    def database_names(cls):
+        pool = DSHelper(cls.__connect_name__).pool
+        database_names = pool.database_names()
+        return database_names
+
+    @classmethod
+    def list_collection_names(cls, database_name=None):
+        pool = DSHelper(cls.__connect_name__).pool
+        if database_name is None:
+            database_name, _ = cls.__route_key__.split(".")
+        return pool.list_collection_names(database_name)
+
     @classmethod
     def count(cls, query: dict):
         pool = DSHelper(cls.__connect_name__).pool
