@@ -56,7 +56,7 @@ class Ks3Oss:
             ret = k.fetch_object(**kwargs)
         if ret:
             if ret.status == 200:
-                return f'{protocol}://{bucket_name}.{region}.{domain}/{key}'
+                return f'{protocol}://{self.instance.name}.{region}.{domain}/{key}'
             else:
                 return False
         else:
